==> haskell-regex-base-0.93.2-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-regex-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-base
version: 0.93.2
id: regex-base-0.93.2-BaAAthubc9o1zwSn6Umtk5
key: regex-base-0.93.2-BaAAthubc9o1zwSn6Umtk5
license: BSD-3-Clause
copyright: Copyright (c) 2006, Christopher Kuklewicz
maintainer: TextRegexLazy@personal.mightyreason.com
author: Christopher Kuklewicz
stability: Seems to work, passes a few tests
homepage: http://sourceforge.net/projects/lazy-regex
package-url: http://darcs.haskell.org/packages/regex-unstable/regex-base/
synopsis: Replaces/Enhances Text.Regex
description:
    Interface API for regex-posix,pcre,parsec,tdfa,dfa
category: Text
abi: d096fda24b17a6940b903df9050e5508
exposed: True
exposed-modules:
    Text.Regex.Base Text.Regex.Base.Context Text.Regex.Base.Impl
    Text.Regex.Base.RegexLike
import-dirs: /usr/lib/ghc-8.6.1/site-local/regex-base-0.93.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/regex-base-0.93.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/regex-base-0.93.2
hs-libraries: HSregex-base-0.93.2-BaAAthubc9o1zwSn6Umtk5
depends:
    array-0.5.2.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    mtl-2.2.2
haddock-interfaces: /usr/share/doc/haskell-regex-base/html/regex-base.haddock
haddock-html: /usr/share/doc/haskell-regex-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-base-0.93.2-36-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-regex-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-base
version: 0.93.2
id: regex-base-0.93.2-8QGsCbNNqfw1S2nCPh78l5
key: regex-base-0.93.2-8QGsCbNNqfw1S2nCPh78l5
license: BSD-3-Clause
copyright: Copyright (c) 2006, Christopher Kuklewicz
maintainer: TextRegexLazy@personal.mightyreason.com
author: Christopher Kuklewicz
stability: Seems to work, passes a few tests
homepage: http://sourceforge.net/projects/lazy-regex
package-url: http://darcs.haskell.org/packages/regex-unstable/regex-base/
synopsis: Replaces/Enhances Text.Regex
description:
    Interface API for regex-posix,pcre,parsec,tdfa,dfa
category: Text
abi: 83228139da58e29dca4b634ed494e335
exposed: True
exposed-modules:
    Text.Regex.Base Text.Regex.Base.Context Text.Regex.Base.Impl
    Text.Regex.Base.RegexLike
import-dirs: /usr/lib/ghc-8.6.3/site-local/regex-base-0.93.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/regex-base-0.93.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/regex-base-0.93.2
hs-libraries: HSregex-base-0.93.2-8QGsCbNNqfw1S2nCPh78l5
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    mtl-2.2.2
haddock-interfaces: /usr/share/doc/haskell-regex-base/html/regex-base.haddock
haddock-html: /usr/share/doc/haskell-regex-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
